@@ -63,6 +63,10 @@ void sequencer(VPN *anchor)
 
 	ENTER("sequencer");
 
+	/* log startup */
+
+	logmsg(STARTUP,0,anchor);
+
 	/* set up buffer and file descriptor set pointers */
 
 	lptr=anchor->lbfr;
